import 'package:cims_apps/application/component/button/button_view.dart';
import 'package:cims_apps/application/theme/color_palette.dart';
import 'package:cims_apps/core/utils/number_formatter.dart';
import 'package:cims_apps/features/dashboard/dashboard_account/view/plan/view/step_invest_plan/result_options_product.dart';
import 'package:flutter/material.dart';

class ResultTotalProduct extends StatelessWidget {
  final int totalInvest;
  final List<Product> listProduct;
  const ResultTotalProduct({super.key, required this.listProduct, required this.totalInvest});

  @override
  Widget build(BuildContext context) {

    return Container(
      decoration: BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.circular(16)
      ),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Padding(
            padding: const EdgeInsets.all(24.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Text('Your Investment Today',
                  style: TextStyle(
                      color: ColorPalette.slate800,
                      fontWeight: FontWeight.w600,
                      fontSize: 16
                  ),
                ),
                GestureDetector(
                  onTap: () => Navigator.pop(context),
                  child: Icon(Icons.close_rounded)
                )
              ],
            ),
          ),
          ...listProduct.asMap().entries.map((e) {
            return Container(
              padding: EdgeInsets.only(left: 16, right: 24, bottom: 16, top: 16),
              decoration: BoxDecoration(
                border: Border(
                  left: BorderSide(
                    color: ColorPalette.investTypeColor[e.value.type]!,
                    width: 8,
                  )
                )
              ),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Expanded(
                    flex: 5,
                    child: Text(e.value.name,
                      style: TextStyle(
                        color: ColorPalette.slate400,
                        fontWeight: FontWeight.w600,
                        fontSize: 16
                      ),
                    )
                  ),
                  Expanded(
                    flex: 7,
                    child: Text(
                      NumberFormatter.numberCurrency(totalInvest / e.value.totalPercent, 'Rp ', 'id_ID'),
                      textAlign: TextAlign.end,
                      style: TextStyle(
                        fontWeight: FontWeight.w700,
                        fontSize: 18,
                        color: ColorPalette.slate800
                      ),
                    )
                  )
                ],
              ),
            );
          }).toList(),
          SizedBox(height: 16),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 24),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Text('Purchase Commission',
                  style: TextStyle(
                    color: ColorPalette.slate400,
                    fontWeight: FontWeight.w600,
                    fontSize: 16
                  ),
                ),
                Text('Free',
                  style: TextStyle(
                    color: ColorPalette.primary,
                    fontSize: 18,
                    fontWeight: FontWeight.w700
                  ),
                )
              ],
            ),
          ),
          SizedBox(height: 16,),
          Container(
            color: ColorPalette.slate200.withOpacity(0.5),
            padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 16),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Text('Total',
                  style: TextStyle(
                      color: ColorPalette.slate400,
                      fontWeight: FontWeight.w600,
                      fontSize: 16
                  ),
                ),
                Text(NumberFormatter.numberCurrency(totalInvest, 'Rp ', 'id_ID'),
                  textAlign: TextAlign.end,
                  style: TextStyle(
                      fontWeight: FontWeight.w700,
                      fontSize: 18,
                      color: ColorPalette.slate800
                  ),
                )
              ],
            ),
          ),
          buttonAgreement(),
          Container(
            padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 16),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Text('Total Payment',
                  style: TextStyle(
                      color: ColorPalette.slate400,
                      fontWeight: FontWeight.w600,
                      fontSize: 16
                  ),
                ),
                Text(NumberFormatter.numberCurrency(totalInvest, 'Rp ', 'id_ID'),
                  textAlign: TextAlign.end,
                  style: TextStyle(
                      fontWeight: FontWeight.w700,
                      fontSize: 18,
                      color: ColorPalette.slate800
                  ),
                )
              ],
            ),
          ),
          ButtonView(
            disabled: true,
            name: 'Subscribe Now',
            onPressed: () {

            },
            disabledBgColor: ColorPalette.slate200.withOpacity(0.5),
            textColor: ColorPalette.slate400,
            textWeight: FontWeight.w700,
            textSize: 20,
            backgroundColor: ColorPalette.primary,
          )
        ],
      ),
    );
  }

  Widget buttonAgreement() {
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 16),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          SizedBox(
            height: 24,
            width: 24,
            child: Radio(
              value: false,
              groupValue: false,
              onChanged: (value) {

              },
              activeColor: ColorPalette.primary,
            ),
          ),
          SizedBox(width: 12,),
          Expanded(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text('I agree to buy the mutual fund on this page and have read and agreed to all the contents of the Prospectus and summary information and understand the risks of my investment decision.',
                    style: TextStyle(
                        fontSize: 16,
                        fontWeight: FontWeight.w600,
                        color: ColorPalette.slate400
                    ),
                  ),
                  GestureDetector(
                      onTap: () {

                      },
                      child: Text('Read More',
                        style: TextStyle(
                            fontSize: 16,
                            fontWeight: FontWeight.w600,
                            decoration: TextDecoration.underline,
                            color: ColorPalette.primary
                        ),
                      )
                  )
                ],
              )
          )
        ],
      ),
    );
  }
}
